Command line of the process, i.e. the executable and the command line arguments, in a character vector. On Unix the program might change its command line, and some programs actually do it.
Usage
ps_cmdline(p = ps_handle())See also
Other process handle functions:
ps_children(),
ps_connections(),
ps_cpu_times(),
ps_create_time(),
ps_cwd(),
ps_descent(),
ps_environ(),
ps_exe(),
ps_handle(),
ps_interrupt(),
ps_is_running(),
ps_kill(),
ps_memory_info(),
ps_name(),
ps_num_fds(),
ps_num_threads(),
ps_open_files(),
ps_pid(),
ps_ppid(),
ps_resume(),
ps_send_signal(),
ps_shared_libs(),
ps_status(),
ps_suspend(),
ps_terminal(),
ps_terminate(),
ps_uids(),
ps_username()
Examples
p <- ps_handle()
p
#> <ps::ps_handle> PID=7371, NAME=R, AT=2026-03-31 18:20:27.39
ps_name(p)
#> [1] "R"
ps_exe(p)
#> [1] "/opt/R/4.5.3/lib/R/bin/exec/R"
ps_cmdline(p)
#> [1] "/opt/R/4.5.3/lib/R/bin/exec/R"
#> [2] "--no-echo"
#> [3] "--no-restore"
#> [4] "--file=/home/runner/work/_temp/ec69e292-a376-40b2-8d2e-7fdf0dbafbc0"