Skip to content

Query the parent processes recursively, up to the first process. (On some platforms, like Windows, the process tree is not a tree and may contain loops, in which case ps_descent() only goes up until the first repetition.)

Usage

ps_descent(p = ps_handle())

Arguments

p

Process handle.

Value

A list of process handles, starting with p, each one is the parent process of the previous one.

Examples

ps_descent()
#> [[1]]
#> <ps::ps_handle> PID=6961, NAME=R, AT=2026-04-20 16:44:45.56573
#> 
#> [[2]]
#> <ps::ps_handle> PID=2146, NAME=Runner.Worker, AT=2026-04-20 16:42:40.69573
#> 
#> [[3]]
#> <ps::ps_handle> PID=2131, NAME=Runner.Listener, AT=2026-04-20 16:42:38.60573
#> 
#> [[4]]
#> <ps::ps_handle> PID=2087, NAME=hosted-compute-, AT=2026-04-20 16:39:35.26573
#> 
#> [[5]]
#> <ps::ps_handle> PID=1, NAME=systemd, AT=2026-04-20 16:39:14.43573
#>