Skip to content

The output is similar to the Unix df command.

Usage

ps_disk_usage(paths = ps_disk_partitions()$mountpoint)

Arguments

paths

The mounted file systems to list. By default all file systems returned by ps_disk_partitions() is listed.

Value

A data frame with columns mountpoint, total, used, available and capacity.

Details

Note that on Unix a small percentage of the disk space (5% typically) is reserved for the superuser. ps_disk_usage() returns the space available to the calling user.

See also

Examples

ps_disk_usage()
#> # A data frame: 3 × 5
#>   mountpoint        total        used   available capacity
#>   <chr>             <dbl>       <dbl>       <dbl>    <dbl>
#> 1 /          154894188544 60560916480 94350049280   0.391 
#> 2 /boot         923156480   131149824   856649728   0.133 
#> 3 /boot/efi     109395456     6399488   102995968   0.0585