Skip to content

Note that in some IDEs, e.g. RStudio or R.app on macOS, the IDE itself opens files from other threads, in addition to the files opened from the main R thread.

Usage

ps_open_files(p = ps_handle())

Arguments

p

Process handle.

Value

Data frame with columns: fd and path. fd is numeric file descriptor on POSIX systems, NA on Windows. path is an absolute path to the file.

Details

For a zombie process it throws a zombie_process error.

Examples

p <- ps_handle()
ps_open_files(p)
#> # A data frame: 16 × 2
#>       fd path                                                        
#>    <int> <chr>                                                       
#>  1     0 pipe:[32634]                                                
#>  2     1 pipe:[32635]                                                
#>  3     2 pipe:[32636]                                                
#>  4     3 /home/runner/work/_temp/ec69e292-a376-40b2-8d2e-7fdf0dbafbc0
#>  5     4 anon_inode:[eventpoll]                                      
#>  6     5 anon_inode:[io_uring]                                       
#>  7     6 pipe:[32644]                                                
#>  8     7 pipe:[32644]                                                
#>  9     8 pipe:[32645]                                                
#> 10     9 pipe:[32645]                                                
#> 11    10 anon_inode:[eventfd]                                        
#> 12    11 pipe:[31526]                                                
#> 13    12 pipe:[31526]                                                
#> 14    17 /tmp/RtmpW3UIAm/Rf1ccb34a44fd6 (deleted)                    
#> 15   142 pipe:[16757]                                                
#> 16   145 pipe:[16758]                                                
f <- file(tmp <- tempfile(), "w")
ps_open_files(p)
#> # A data frame: 17 × 2
#>       fd path                                                        
#>    <int> <chr>                                                       
#>  1     0 pipe:[32634]                                                
#>  2     1 pipe:[32635]                                                
#>  3     2 pipe:[32636]                                                
#>  4     3 /home/runner/work/_temp/ec69e292-a376-40b2-8d2e-7fdf0dbafbc0
#>  5     4 anon_inode:[eventpoll]                                      
#>  6     5 anon_inode:[io_uring]                                       
#>  7     6 pipe:[32644]                                                
#>  8     7 pipe:[32644]                                                
#>  9     8 pipe:[32645]                                                
#> 10     9 pipe:[32645]                                                
#> 11    10 anon_inode:[eventfd]                                        
#> 12    11 pipe:[31526]                                                
#> 13    12 pipe:[31526]                                                
#> 14    17 /tmp/RtmpW3UIAm/Rf1ccb34a44fd6 (deleted)                    
#> 15    18 /tmp/RtmpW3UIAm/file1ccb1004111e                            
#> 16   142 pipe:[16757]                                                
#> 17   145 pipe:[16758]                                                
close(f)
unlink(tmp)
ps_open_files(p)
#> # A data frame: 16 × 2
#>       fd path                                                        
#>    <int> <chr>                                                       
#>  1     0 pipe:[32634]                                                
#>  2     1 pipe:[32635]                                                
#>  3     2 pipe:[32636]                                                
#>  4     3 /home/runner/work/_temp/ec69e292-a376-40b2-8d2e-7fdf0dbafbc0
#>  5     4 anon_inode:[eventpoll]                                      
#>  6     5 anon_inode:[io_uring]                                       
#>  7     6 pipe:[32644]                                                
#>  8     7 pipe:[32644]                                                
#>  9     8 pipe:[32645]                                                
#> 10     9 pipe:[32645]                                                
#> 11    10 anon_inode:[eventfd]                                        
#> 12    11 pipe:[31526]                                                
#> 13    12 pipe:[31526]                                                
#> 14    17 /tmp/RtmpW3UIAm/Rf1ccb34a44fd6 (deleted)                    
#> 15   142 pipe:[16757]                                                
#> 16   145 pipe:[16758]