Skip to content

ps_ppid() returns the parent pid, ps_parent() returns a ps_handle of the parent.

Usage

ps_ppid(p = ps_handle())

ps_parent(p = ps_handle())

Arguments

p

Process handle.

Value

ps_ppid() returns and integer scalar, the pid of the parent of p. ps_parent() returns a ps_handle.

Details

On POSIX systems, if the parent process terminates, another process (typically the pid 1 process) is marked as parent. ps_ppid() and ps_parent() will return this process then.

Both ps_ppid() and ps_parent() work for zombie processes.

Examples

p <- ps_handle()
p
#> <ps::ps_handle> PID=7371, NAME=R, AT=2026-03-31 18:20:27.39
ps_ppid(p)
#> [1] 2150
ps_parent(p)
#> <ps::ps_handle> PID=2150, NAME=Runner.Worker, AT=2026-03-31 18:19:00.66