Data frame with the currently running processes.
Arguments
- user
Username, to filter the results to matching processes.
- after
Start time (
POSIXt), to filter the results to processes that started after this.- columns
Columns to include in the result. If
NULL(the default), then a default set of columns are returned, see below. The columns are shown in the same order they are specified incolumns, but each column is included at most once. Use"*"to include all possible columns, and prefix a column name with-to remove it.
Details
Columns shown by default, if columns is not given or NULL:
pid: Process ID.ppid: Process ID of parent process.name: Process name.username: Name of the user (real uid on POSIX).status: I.e. running, sleeping, etc.user: User CPU time.system: System CPU time.rss: Resident set size, the amount of memory the process currently uses. Does not include memory that is swapped out. It does include shared libraries.vms: Virtual memory size. All memory the process has access to.created: Time stamp when the process was created.ps_handle:ps_handleobjects, in a list column.
Additional columns that can be requested via columns:
cmdline: Command line, in a single string, fromps_cmdline().vcmdline: Likecmdline, but each command line argument in a separate string.cwd: Current working directory, fromps_cwd().exe: Path of the executable of the process, fromps_exe().num_fds: Number of open file descriptors, fromps_num_fds().num_threads: Number of threads, fromps_num_threads().cpu_children_user: Seeps_cpu_times().cpu_children_system: Seeps_cpu_times().terminal: Terminal device, fromps_terminal().uid_real: Real user id, fromps_uids().uid_effective: Effective user id, fromps_uids().uid_saved: Saved user id, fromps_uids().gid_real: Real group id, fromps_gids().gid_effective: Effective group id, fromps_gids().gid_saved: Saved group id, fromps_gids().mem_shared: Seeps_memory_info().mem_text: Seeps_memory_info().mem_data: Seeps_memory_info().mem_lib: Seeps_memory_info().mem_dirty: Seeps_memory_info().mem_pfaults: Seeps_memory_info().mem_pageins: Seeps_memory_info().mem_maxrss: Seeps_memory_full_info().mem_uss: Seeps_memory_full_info().mem_pss: Seeps_memory_full_info().mem_swap: Seeps_memory_full_info().
Use "*" in columns to include all columns.
Processes for which a handle cannot be created (e.g. due to insufficient
permissions, or because the process exited between enumeration and handle
creation) are silently omitted from the result. This means ps() may
return fewer processes than system tools such as tasklist on Windows.