Skip to content

Query the parent processes recursively, up to the first process. (On some platforms, like Windows, the process tree is not a tree and may contain loops, in which case ps_descent() only goes up until the first repetition.)

Usage

ps_descent(p = ps_handle())

Arguments

p

Process handle.

Value

A list of process handles, starting with p, each one is the parent process of the previous one.

Examples

ps_descent()
#> [[1]]
#> <ps::ps_handle> PID=7371, NAME=R, AT=2026-03-31 18:20:27.39
#> 
#> [[2]]
#> <ps::ps_handle> PID=2150, NAME=Runner.Worker, AT=2026-03-31 18:19:00.66
#> 
#> [[3]]
#> <ps::ps_handle> PID=2135, NAME=Runner.Listener, AT=2026-03-31 18:18:58.42
#> 
#> [[4]]
#> <ps::ps_handle> PID=2098, NAME=hosted-compute-, AT=2026-03-31 18:18:57.75
#> 
#> [[5]]
#> <ps::ps_handle> PID=1, NAME=systemd, AT=2026-03-31 18:18:23.35
#>