The output is similar to the Unix df command.
Usage
ps_disk_usage(paths = ps_disk_partitions()$mountpoint)Arguments
- paths
The mounted file systems to list. By default all file systems returned by
ps_disk_partitions()is listed.
Details
Note that on Unix a small percentage of the disk space (5% typically)
is reserved for the superuser. ps_disk_usage() returns the space
available to the calling user.
See also
Other disk functions:
ps_disk_io_counters(),
ps_disk_partitions()