Note that in some IDEs, e.g. RStudio or R.app on macOS, the IDE itself opens files from other threads, in addition to the files opened from the main R thread.
Usage
ps_open_files(p = ps_handle())Value
Data frame with columns: fd and path. fd is numeric
file descriptor on POSIX systems, NA on Windows. path is an
absolute path to the file.
See also
Other process handle functions:
ps_children(),
ps_cmdline(),
ps_connections(),
ps_cpu_times(),
ps_create_time(),
ps_cwd(),
ps_descent(),
ps_environ(),
ps_exe(),
ps_handle(),
ps_interrupt(),
ps_is_running(),
ps_kill(),
ps_memory_info(),
ps_name(),
ps_num_fds(),
ps_num_threads(),
ps_pid(),
ps_ppid(),
ps_resume(),
ps_send_signal(),
ps_shared_libs(),
ps_status(),
ps_suspend(),
ps_terminal(),
ps_terminate(),
ps_uids(),
ps_username()
Examples
p <- ps_handle()
ps_open_files(p)
#> # A data frame: 16 × 2
#> fd path
#> <int> <chr>
#> 1 0 pipe:[32634]
#> 2 1 pipe:[32635]
#> 3 2 pipe:[32636]
#> 4 3 /home/runner/work/_temp/ec69e292-a376-40b2-8d2e-7fdf0dbafbc0
#> 5 4 anon_inode:[eventpoll]
#> 6 5 anon_inode:[io_uring]
#> 7 6 pipe:[32644]
#> 8 7 pipe:[32644]
#> 9 8 pipe:[32645]
#> 10 9 pipe:[32645]
#> 11 10 anon_inode:[eventfd]
#> 12 11 pipe:[31526]
#> 13 12 pipe:[31526]
#> 14 17 /tmp/RtmpW3UIAm/Rf1ccb34a44fd6 (deleted)
#> 15 142 pipe:[16757]
#> 16 145 pipe:[16758]
f <- file(tmp <- tempfile(), "w")
ps_open_files(p)
#> # A data frame: 17 × 2
#> fd path
#> <int> <chr>
#> 1 0 pipe:[32634]
#> 2 1 pipe:[32635]
#> 3 2 pipe:[32636]
#> 4 3 /home/runner/work/_temp/ec69e292-a376-40b2-8d2e-7fdf0dbafbc0
#> 5 4 anon_inode:[eventpoll]
#> 6 5 anon_inode:[io_uring]
#> 7 6 pipe:[32644]
#> 8 7 pipe:[32644]
#> 9 8 pipe:[32645]
#> 10 9 pipe:[32645]
#> 11 10 anon_inode:[eventfd]
#> 12 11 pipe:[31526]
#> 13 12 pipe:[31526]
#> 14 17 /tmp/RtmpW3UIAm/Rf1ccb34a44fd6 (deleted)
#> 15 18 /tmp/RtmpW3UIAm/file1ccb1004111e
#> 16 142 pipe:[16757]
#> 17 145 pipe:[16758]
close(f)
unlink(tmp)
ps_open_files(p)
#> # A data frame: 16 × 2
#> fd path
#> <int> <chr>
#> 1 0 pipe:[32634]
#> 2 1 pipe:[32635]
#> 3 2 pipe:[32636]
#> 4 3 /home/runner/work/_temp/ec69e292-a376-40b2-8d2e-7fdf0dbafbc0
#> 5 4 anon_inode:[eventpoll]
#> 6 5 anon_inode:[io_uring]
#> 7 6 pipe:[32644]
#> 8 7 pipe:[32644]
#> 9 8 pipe:[32645]
#> 10 9 pipe:[32645]
#> 11 10 anon_inode:[eventfd]
#> 12 11 pipe:[31526]
#> 13 12 pipe:[31526]
#> 14 17 /tmp/RtmpW3UIAm/Rf1ccb34a44fd6 (deleted)
#> 15 142 pipe:[16757]
#> 16 145 pipe:[16758]