A convenient format for passing between processes, naming semaphores, or using as a directory/file name. Will always be 12 alphanumeric characters, with the first character guarantied to be a letter. Encodes the pid and creation time for a process.
Usage
ps_string(p = ps_handle())Value
A process string (scalar character), that can be passed to
ps_handle() in place of a pid.