ps_string: Encode a 'ps_handle' as a short string

View source: R/string.R

ps_stringR Documentation

Encode a ps_handle as a short string

Description

A convenient format for passing between processes, naming semaphores, or using as a directory/file name. Will always be 12 alphanumeric characters, with the first character guarantied to be a letter. Encodes the pid and creation time for a process.

Usage

ps_string(p = ps_handle())

Arguments

p

Process handle.

Value

A process string (scalar character), that can be passed to ps_handle() in place of a pid.

Examples


(p <- ps_handle())
(str <- ps_string(p))
ps_handle(pid = str)


ps documentation built on April 20, 2026, 5:07 p.m.